Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog and this project adheres to Semantic Versioning.

Unreleased

0.0.3 - 2022-10-14

  • Supports the nightly compilers between 2022-06-20 and 2022-10-13 (and possibly newer ones).

0.0.2 - 2021-09-10

  • Supports the nightly compilers between 2021-09-04 and 2022-04-08 (and possibly older ones).
  • Added
    • interlock::hl::slice::*RbTree{SliceRef, Vec}IntervalRwLock - while the existing *RbTreeSliceIntervalRwLock encompasses them, its use of projection causes inconveniences with the current non-Chalk trait solver.
    • interlock::hl::slice::SliceIntervalRwLock::{, async_, try_}{read, write}_boxed
    • interlock::hl::slice::SliceIntervalRwLock::update_container

0.0.1 - 2021-09-09